"""Main module."""
import datetime
import logging

from fw_gear_fsl_fslhd.interfaces import FSLHD, get_nifti_header

log = logging.getLogger(__name__)


def run(nifti_file_path, nifti_file_name):

    """Run flshd and write nifti metadata

    Args:
        nifti file path
        nifti file name

    Returns:
        (.metadata.json): file including metadata extracted by fslhd form nifti file
    """

    log.info("This is the beginning of the run file")
    log.info("  start: %s" % datetime.datetime.utcnow())

    # FSLHD.help()
    in_file = nifti_file_path + "/" + nifti_file_name

    # interface
    hd_obj = FSLHD()

    # get xml file generated by fslhd
    hd_obj.inputs.in_file = in_file
    hd_obj.inputs.x_param = True
    hd_obj.inputs.out_file = "/tmp/flhd_interface_xml.xml"

    log.info(hd_obj.cmdline)  # shows command line ran

    hdr_out = hd_obj.run()
    fslhd_xml = hdr_out.outputs.out_file

    # get txt file generated by fslhd
    hd_obj.inputs.x_param = False
    hd_obj.inputs.out_file = "/tmp/fslhd_interface_xml.txt"

    log.info(hd_obj.cmdline)  # shows command line ran

    hdr_out = hd_obj.run()
    fslhd_txt = hdr_out.outputs.out_file

    nifti_header = get_nifti_header(fslhd_xml, fslhd_txt)

    return nifti_header
